@@ -1,6 +1,7 @@
 import io
 from datetime import datetime
 
+import pkg_resources
 from PIL import Image, ImageDraw, ImageFont, ImageOps
 
 WIDTH = 300
@@ -10,7 +11,7 @@ FONT = '../resources/font.ttf'
 
 
 def draw_date(draw: ImageDraw, date: datetime):
-    font = ImageFont.truetype(FONT, FONT_SIZE)
+    font = ImageFont.truetype(pkg_resources.resource_filename(__name__, 'resources/font.ttf'), FONT_SIZE)
     draw.text((10, 30), date.strftime("%d-%m-%Y"), font=font, fill=(0, 0, 0))
 
 
